#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_EXPPDF_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_EXPPDF_HPP_INCLUDED

#include <nt2/statistics/include/functions/scalar/exppdf.hpp>

#endif
